@@ -1,12 +1,3 @@
-__all__ = ["format_number"]
-
-from datetime import datetime
-
-
-def format_date_month(date: datetime) -> str:
-    return date.strftime("%d/%m")
-
-
 def format_number(value: float | int, *, format_spec=".1f", parenthesized_negative=True) -> str:
     def format_value(value: float | int) -> str:
         return format(value, format_spec)
