@@ -1,5 +1,4 @@
 from dataclasses import dataclass
-from pathlib import Path
 from types import ModuleType
 from typing import Iterable, Iterator, TypeAlias, cast
 
@@ -8,9 +7,9 @@ from parsy import ParseError, any_char, char_from, regex, seq, string
 from pptx.table import Table, _Cell, _Row, _RowCollection
 from tabulate import tabulate  # type: ignore
 
-from dbnomics_pptx_tools.dbnomics_api import load_series_from_cache
 from dbnomics_pptx_tools.formatters import format_number
 from dbnomics_pptx_tools.metadata import TableSpec
+from dbnomics_pptx_tools.repo import SeriesRepo
 
 __all__ = ["extract_table_zones", "format_table", "replace_cell_text", "update_table"]
 
@@ -43,13 +42,13 @@ class TableZones:
     periods: list[Period]
 
 
-def extract_table_zones(table: Table, *, adhoc_tables_module: ModuleType | None, table_name: str) -> TableZones | None:
+def extract_table_zones(table: Table, *, adhoc_module: ModuleType | None, table_name: str) -> TableZones | None:
     header_row_index = find_header_row_index(table)
     if header_row_index is None:
         logger.debug("Could not find the row corresponding to the table header")
         return None
     periods = parse_header_periods(
-        table, adhoc_tables_module=adhoc_tables_module, header_row_index=header_row_index, table_name=table_name
+        table, adhoc_module=adhoc_module, header_row_index=header_row_index, table_name=table_name
     )
     if periods is None:
         logger.debug("Could not parse the periods in the table header")
@@ -91,12 +90,10 @@ def format_table(table: Table) -> str:
     return tabulate(tabular_data)
 
 
-def get_period_cells(
-    header_cells: list[_Cell], *, adhoc_tables_module: ModuleType | None, table_name: str
-) -> list[_Cell]:
+def get_period_cells(header_cells: list[_Cell], *, adhoc_module: ModuleType | None, table_name: str) -> list[_Cell]:
     period_cells = header_cells[1:]
-    if adhoc_tables_module is not None:
-        filtered_period_cells = adhoc_tables_module.filter_period_cells(period_cells, table_name=table_name)
+    if adhoc_module is not None and hasattr(adhoc_module, "filter_period_cells"):
+        filtered_period_cells = adhoc_module.filter_period_cells(period_cells, table_name=table_name)
         if filtered_period_cells is not None:
             return filtered_period_cells
     return period_cells
@@ -125,11 +122,11 @@ def parse_header_period(text: str) -> Period:
 
 
 def parse_header_periods(
-    table: Table, *, adhoc_tables_module: ModuleType | None, header_row_index: int, table_name: str
+    table: Table, *, adhoc_module: ModuleType | None, header_row_index: int, table_name: str
 ) -> list[Period] | None:
     rows = cast(_RowCollection, table.rows)
     header_cells = list(rows[header_row_index].cells)
-    period_cells = get_period_cells(header_cells, adhoc_tables_module=adhoc_tables_module, table_name=table_name)
+    period_cells = get_period_cells(header_cells, adhoc_module=adhoc_module, table_name=table_name)
     period_cells_text = [cell.text for cell in period_cells]
     logger.debug("Parsing period cells: %r", period_cells_text)
 
@@ -157,8 +154,8 @@ def replace_cell_text(cell: _Cell, text: str):
 def update_table(
     table: Table,
     *,
-    adhoc_tables_module: ModuleType | None,
-    dbnomics_api_cache_dir: Path,
+    adhoc_module: ModuleType | None,
+    repo: SeriesRepo,
     table_name: str,
     table_spec: TableSpec,
     table_zones: TableZones,
@@ -168,16 +165,16 @@ def update_table(
             update_table_cell(
                 table,
                 col_index=col_index,
-                dbnomics_api_cache_dir=dbnomics_api_cache_dir,
                 period=str(period),
+                repo=repo,
                 row_index=row_index,
                 row_label=row_label,
                 table_spec=table_spec,
             )
-    if adhoc_tables_module is not None:
-        adhoc_tables_module.process_adhoc_table(
+    if adhoc_module is not None and hasattr(adhoc_module, "process_adhoc_table"):
+        adhoc_module.process_adhoc_table(
             table,
-            dbnomics_api_cache_dir=dbnomics_api_cache_dir,
+            repo=repo,
             table_name=table_name,
             table_spec=table_spec,
             table_zones=table_zones,
@@ -188,8 +185,8 @@ def update_table_cell(
     table: Table,
     *,
     col_index: int,
-    dbnomics_api_cache_dir: Path,
     period: str,
+    repo: SeriesRepo,
     row_index: int,
     row_label: str,
     table_spec: TableSpec,
@@ -198,7 +195,7 @@ def update_table_cell(
     if series_id is None:
         logger.warning("Could not find the series ID from the row label %r, ignoring row", row_label)
         return
-    df = load_series_from_cache(series_id, cache_dir=dbnomics_api_cache_dir)
+    df = repo.load(series_id)
     observations = df[df["original_period"] == period].value
     cell = table.cell(row_index, col_index)
     if observations.empty:
